WindowAttributes

Struct WindowAttributes 

pub struct WindowAttributes {
    pub resizable: bool,
    pub maximized: bool,
    pub visible: bool,
    pub decorations: bool,
    pub title: String,
    pub size: Option<Size>,
    pub min_size: Option<Size>,
    pub max_size: Option<Size>,
    pub position: Option<Point>,
    pub icon: Option<Resource<PixelImage>>,
}
Attributes for creating a new window.

Fields

resizable: boolmaximized: boolvisible: booldecorations: booltitle: Stringsize: Option<Size>min_size: Option<Size>max_size: Option<Size>position: Option<Point>icon: Option<Resource<PixelImage>>

Implementations

Source

impl WindowAttributes

pub fn with_title(&mut self, title: impl Into<String>) -> &mut Self

Sets the initial title of the window in the title bar.

The default is "Ribir App".

pub fn with_resizable(&mut self, resizable: bool) -> &mut Self

Sets whether the window should be resizable or not. The default is true.

pub fn with_size(&mut self, size: Size) -> &mut Self

Sets the initial size of the window client area, window excluding the title bar and borders.

pub fn with_min_size(&mut self, size: Size) -> &mut Self

Sets the minimum size of the window client area

pub fn with_max_size(&mut self, size: Size) -> &mut Self

Sets the maximum size of the window client area

pub fn with_position(&mut self, position: Point) -> &mut Self

Sets the initial position of the window in screen coordinates.

pub fn with_maximized(&mut self, maximized: bool) -> &mut Self

Sets whether the window should be maximized when it is first shown.

pub fn with_visible(&mut self, visible: bool) -> &mut Self

Sets whether the window should be visible when it is first shown.

pub fn with_decorations(&mut self, decorations: bool) -> &mut Self

Sets whether the window should have a border, a title bar, etc.

pub fn with_icon(&mut self, icon: Resource<PixelImage>) -> &mut Self

Sets the icon of the window.