JustifyContent

Enum JustifyContent 

pub enum JustifyContent {
    Start,
    Center,
    End,
    SpaceBetween,
    SpaceAround,
    SpaceEvenly,
}
How the children should be placed along the main axis in a flex layout.

Variants



Start

Place the children as close to the start of the main axis as possible.



Center

Place the children as close to the middle of the main axis as possible.



End

Place the children as close to the end of the main axis as possible.



SpaceBetween

The children are evenly distributed within the alignment container along the main axis. The spacing between each pair of adjacent items is the same. The first item is flush with the main-start edge, and the last item is flush with the main-end edge.



SpaceAround

The children are evenly distributed within the alignment container along the main axis. The spacing between each pair of adjacent items is the same. The empty space before the first and after the last item equals half of the space between each pair of adjacent items.



SpaceEvenly

The children are evenly distributed within the alignment container along the main axis. The spacing between each pair of adjacent items, the main-start edge and the first item, and the main-end edge and the last item, are all exactly the same.