Flex

Struct Flex 

pub struct Flex {
    pub reverse: bool,
    pub wrap: bool,
    pub direction: Direction,
    pub align_items: Align,
    pub justify_content: JustifyContent,
    pub item_gap: f32,
    pub line_gap: f32,
}

Fields

reverse: bool

Reverse the main axis.

wrap: bool

Whether flex items are forced onto one line or can wrap onto multiple lines

direction: Direction

Sets how flex items are placed in the flex container defining the main axis and the direction

align_items: Align

How the children should be placed along the cross axis in a flex layout.

justify_content: JustifyContent

How the children should be placed along the main axis in a flex layout.

item_gap: f32

Define item between gap in main axis

line_gap: f32

Define item between gap in cross axis