pub struct Container {
pub size: Size2D<f32, LogicUnit>,
}Expand description
Widget with fixed size as a container for its child.
Fields
size: Size2D<f32, LogicUnit>Trait Implementations
Sourceimpl Query for Container
impl Query for Container
Sourceimpl Render for Container
impl Render for Container
Sourcefn perform_layout(
&self,
clamp: BoxClamp,
ctx: &mut LayoutCtx<'_>,
) -> Size2D<f32, LogicUnit>
fn perform_layout( &self, clamp: BoxClamp, ctx: &mut LayoutCtx<'_>, ) -> Size2D<f32, LogicUnit>
Do the work of computing the layout for this widget, and return the
size it need. Read more
Sourcefn paint(&self, _: &mut PaintingCtx<'_>)
fn paint(&self, _: &mut PaintingCtx<'_>)
paint is a low level trait to help you draw your widget to paint device
across PaintingCtx::painter by itself coordinate system. Not care
about children’s paint in this method, framework will call children’s
paint individual. And framework guarantee always paint parent before
children.Sourcefn only_sized_by_parent(&self) -> bool
fn only_sized_by_parent(&self) -> bool
Whether the constraints from parent are the only input to detect the
widget size, and child nodes’ size not affect its size.
Sourcefn hit_test(&self, ctx: &HitTestCtx, pos: Point2D<f32, LogicUnit>) -> HitTest
fn hit_test(&self, ctx: &HitTestCtx, pos: Point2D<f32, LogicUnit>) -> HitTest
Determines the set of render widgets located at the given position.
fn get_transform(&self) -> Option<Transform2D<f32, LogicUnit, LogicUnit>>
impl SingleChild for Container