pub struct Divider {
pub extent: f32,
pub color: Brush,
pub direction: Direction,
pub thickness: f32,
pub indent: f32,
pub end_indent: f32,
}Expand description
Divider is a thin horizontal or vertical line, with padding on either side.
example
// use default Divider default settings
let widget = fn_widget! {
@Column {
@SizedBox { size: Size::new(10., 0.) }
@Divider { extent: 20. }
@SizedBox { size: Size::new(10., 0.) }
}
};
// use custom settings
let widget = fn_widget! {
@Column {
@SizedBox { size: Size::new(10., 0.) }
@Divider {
extent: 20.,
color: Color::RED,
direction: Direction::Horizontal,
// Thickness of line
thickness: 2.,
// front indentation distance
indent: 10.,
// behind indentation distance
end_indent: 10.,
}
@SizedBox { size: Size::new(10., 0.) }
}
};Fields
extent: f32color: Brushdirection: Directionthickness: f32indent: f32end_indent: f32Trait Implementations
Sourceimpl Query for Divider
impl Query for Divider
Sourceimpl Render for Divider
impl Render for Divider
Sourcefn perform_layout(
&self,
clamp: BoxClamp,
_: &mut LayoutCtx<'_>,
) -> Size2D<f32, LogicUnit>
fn perform_layout( &self, clamp: BoxClamp, _: &mut LayoutCtx<'_>, ) -> Size2D<f32, LogicUnit>
Do the work of computing the layout for this widget, and return the
size it need. Read more
Sourcefn paint(&self, ctx: &mut PaintingCtx<'_>)
fn paint(&self, ctx: &mut PaintingCtx<'_>)
paint is a low level trait to help you draw your widget to paint device
across PaintingCtx::painter by itself coordinate system. Not care
about children’s paint in this method, framework will call children’s
paint individual. And framework guarantee always paint parent before
children.Sourcefn only_sized_by_parent(&self) -> bool
fn only_sized_by_parent(&self) -> bool
Whether the constraints from parent are the only input to detect the
widget size, and child nodes’ size not affect its size.
Sourcefn hit_test(&self, ctx: &HitTestCtx, pos: Point2D<f32, LogicUnit>) -> HitTest
fn hit_test(&self, ctx: &HitTestCtx, pos: Point2D<f32, LogicUnit>) -> HitTest
Determines the set of render widgets located at the given position.
fn get_transform(&self) -> Option<Transform2D<f32, LogicUnit, LogicUnit>>