pub struct Text {
pub text: CowArc<str>,
pub foreground: Brush,
pub text_style: CowArc<TextStyle>,
pub path_style: PathStyle,
pub overflow: Overflow,
pub text_align: TextAlign,
}Expand description
The text widget display text with a single style.
Fields
text: CowArc<str>foreground: Brushtext_style: CowArc<TextStyle>path_style: PathStyleoverflow: Overflowtext_align: TextAlignTrait Implementations
Sourceimpl Query for Text
impl Query for Text
Sourceimpl Render for Text
impl Render for Text
Sourcefn perform_layout(
&self,
clamp: BoxClamp,
_: &mut LayoutCtx<'_>,
) -> Size2D<f32, LogicUnit>
fn perform_layout( &self, clamp: BoxClamp, _: &mut LayoutCtx<'_>, ) -> Size2D<f32, LogicUnit>
Do the work of computing the layout for this widget, and return the
size it need. Read more
Sourcefn only_sized_by_parent(&self) -> bool
fn only_sized_by_parent(&self) -> bool
Whether the constraints from parent are the only input to detect the
widget size, and child nodes’ size not affect its size.
Sourcefn paint(&self, ctx: &mut PaintingCtx<'_>)
fn paint(&self, ctx: &mut PaintingCtx<'_>)
paint is a low level trait to help you draw your widget to paint device
across PaintingCtx::painter by itself coordinate system. Not care
about children’s paint in this method, framework will call children’s
paint individual. And framework guarantee always paint parent before
children.Sourcefn hit_test(&self, ctx: &HitTestCtx, pos: Point2D<f32, LogicUnit>) -> HitTest
fn hit_test(&self, ctx: &HitTestCtx, pos: Point2D<f32, LogicUnit>) -> HitTest
Determines the set of render widgets located at the given position.
fn get_transform(&self) -> Option<Transform2D<f32, LogicUnit, LogicUnit>>
impl StructuralPartialEq for Text
Sourceimpl VisualText for Text
impl VisualText for Text
fn text(&self) -> CowArc<str>
fn text_style(&self) -> &TextStyle
fn text_align(&self) -> TextAlign
fn overflow(&self) -> Overflow
fn text_layout( &self, typography_store: &TypographyStore, bound: Size2D<f32, LogicUnit>, ) -> VisualGlyphs